hyperkyc_flutter library

Classes

HyperKyc
HyperKyc Flutter SDK can be used to create workflows to capture images of ID cards, photos of the face of the user, and perform other operations like face matches, etc all within itself to ease up integration friction on the client end.

Enums

HKThemeMode
Theme mode for the HyperKyc SDK.

Extensions

HKThemeModeExtension on HKThemeMode
Extension to convert HKThemeMode to string for native bridge

Typedefs

HyperKycEventListener = void Function(Map<String, dynamic> event)
Listener function type for KYC events