HyperKycResult class

HyperKycResult contains the result from the HyperKyc workflow

Constructors

HyperKycResult({HyperKycStatus? status, String? transactionId, Map? details, int? errorCode, String? errorMessage, String? latestModule, String? rawDataJsonString})
Constructor
HyperKycResult.fromMap(Map json)
Convert map to HyperKycResult object
factory

Properties

details → Map?
details will containSDK response
final
errorCode → int?
State errorCode of error occurred during the hyperkyc flow
final
errorMessage → String?
State errorMessage of error occurred during the hyperkyc flow
final
hashCode → int
The hash code for this object.
no setterinherited
latestModule → String?
State latestModule of the module when error occurred during the hyperkyc flow
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → HyperKycStatus?
State whether the hyperkyc flow was success or cancelled or failure.
final
transactionId → String?
transactionId used for the flow
final

Methods

getRawDataJsonString() → String?
Obtain responseDump in HyperKyc demo app only (Demo purpose only)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert HyperKycResult object to Map - Exclude #rawDataJsonString from toMap
toString() → String
Overridden toString method - Exclude #rawDataJsonString from toString
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited