HKThemeMode enum

Theme mode for the HyperKyc SDK.

This enum specifies how the SDK should handle theming:

  • light: Force light theme regardless of system settings
  • dark: Force dark theme regardless of system settings
  • system: Follow the device's system theme settings

Usage:

var config = HyperKycConfig.fromAppIdAppKey(
  appId: appId,
  appKey: appKey,
  workflowId: workflowId,
  transactionId: transactionId,
);
config.setHKThemeMode(hkThemeMode: HKThemeMode.system); // Follow system theme
// or
config.setHKThemeMode(hkThemeMode: HKThemeMode.dark);   // Force dark theme
// or
config.setHKThemeMode(hkThemeMode: HKThemeMode.light);  // Force light theme
Inheritance
Available extensions

Values

light → const HKThemeMode

Force light theme regardless of system settings

dark → const HKThemeMode

Force dark theme regardless of system settings

system → const HKThemeMode

Follow the device's system theme settings

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeString() String

Available on HKThemeMode, provided by the HKThemeModeExtension extension

Convert HKThemeMode to string for native bridge
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HKThemeMode>
A constant List of the values in this enum, in order of their declaration.